module.exports = defineTest({
	description: 'uses correct scope in for statement (#1538)'
});
